@@ -51,7 +51,9 @@ page_template_default = """
 """
 feed_update_template_default = """%title, %timestamp <hr>"""
 item_comment_prefix = "feed item: "
-print_version_keywords_default = [u"версия для печати", u"printable version"]
+print_version_keywords_default = [u"printable version", u"версия для печати"]
+single_page_keywords_default = [u"single page", u"одной страницей"]
+next_page_keywords_default = [u"next page"]
 cached_comment_prefix = "cached item: "
 
 
@@ -292,7 +294,7 @@ class Downloader:
             urllib.urlretrieve(url, filename)
         except Exception, ex:
             if self.__callback:
-                self.__callback(("error", ex))
+                self.__callback(("error", ex, None))
 
 
     def wait_completion(self):
@@ -308,9 +310,11 @@ class Item:
     """
 
     def __init__(self, url = None, tag = None, base = None, path = "", cache_path = "", callback = None,
-        page_template = None, print_version_keywords = None, try_use_print_version = True,
-        allow_scripts = False, as_is = False, content_kwargs = None, reformatter_url = None, next_page_keyword = None,
-        downloader = None):
+        print_version_keywords = print_version_keywords_default,
+        single_page_keywords = single_page_keywords_default,
+        next_page_keywords = next_page_keywords_default,
+        page_template = None, allow_scripts = False, content_kwargs = None,
+        reformatter_url = None, downloader = None):
         """ It is clear that this is constructor :)
 
         Item is represented either by its content, when tag is specified, or by reference
@@ -322,13 +326,12 @@ class Item:
         page_template - used for creating cached items.
         print_version_keywords - a list of phrases to scan html document searching for reference to
         printable version.
-        try_use_print_version - search for reference to printable version should be performed.
         allow_scripts - do not remove script tags from item before caching.
-        as_is - do not try to reformat html document for small screens.
         content_kwargs - it is passed to BeautifulSoup's find method. It is usually
         tag name and its attributes.
         reformatter_url - format string (%s is replaced with url from item).
-        next_page_keyword - the name of the link that leads to the next page of document if any
+        next_page_keywords - a list of names of links which leads to the next page of document if any
+        single_page_keywords - a list of names of links which leads to the single page version
         Used to process html document through online services such as Skweezer.
         """
         self.__url = url
@@ -336,23 +339,20 @@ class Item:
         self.__base = base
         self.__path = path
         self.__cache_path = cache_path
-        self.__try_use_print_version = try_use_print_version
         self.__allow_scripts = allow_scripts
         self.__page_template = page_template_default
         if page_template:
             self.__page_template = page_template
-        self.__print_version_keywords = print_version_keywords_default
-        if print_version_keywords:
-            self.__print_version_keywords = print_version_keywords
+        self.__print_version_keywords = print_version_keywords
+        self.__single_page_keywords = single_page_keywords
+        self.__next_page_keywords = next_page_keywords
         self.__callback = callback
         self.__attrs_for_fix = [("a", "href"), ("iframe", "src"), ("object", "data"), ("form", "action")]
         self.__attrs_for_cache = \
             [("applet", "codebase"), ("object", "codebase"), ("script", "src"), ("img", "src"), ("input", "src")]
         self.title = "untitled"
-        self.__as_is = as_is
         self.__content_kwargs = content_kwargs
         self.__reformatter_url = reformatter_url
-        self.__next_page_keyword = next_page_keyword
         self.__next_page_a = None
         self.__downloader = downloader
         if not self.__downloader:
@@ -413,15 +413,15 @@ class Item:
 
     def __cache_next_page(self, html, base):
         try:
-            text = html.find(text=lambda t: t.strip().lower() == self.__next_page_keyword.strip().lower())
+            text = html.find(text=lambda t: t.strip().lower() in self.__next_page_keywords)
             if text:
                 a = text.findParent(lambda t: t.name == "a" and t.has_key("href"))
                 if a:
                     url = urljoin(base, a["href"])
                     item = Item(url = url, path = self.__path, cache_path = self.__cache_path,
                         callback = self.__callback, page_template = self.__page_template,
-                        try_use_print_version = False, allow_scripts = self.__allow_scripts,
-                        content_kwargs = self.__content_kwargs, next_page_keyword = self.__next_page_keyword)
+                        allow_scripts = self.__allow_scripts, next_page_keywords = self.__next_page_keywords,
+                        content_kwargs = self.__content_kwargs)
                     item.process()
                     a["href"] = item.save()
                     return a
@@ -429,6 +429,20 @@ class Item:
             self.__report("error", ex)
 
 
+    def __find_single_page(self, html, base, referer):
+        try:
+            text = html.find(text=lambda t: t.strip().lower() in self.__single_page_keywords)
+            if text:
+                a = text.findParent(lambda t: t.name == "a" and t.has_key("href"))
+                if a:
+                    url = urljoin(base, a["href"])
+                    (new_html, new_base, real_url) = self.__get_page_html(url, headers={"Referer": referer})
+                    return (new_html, new_base, True)
+        except Exception, ex:
+            self.__report("error", ex)
+        return (html, base, False)
+
+
     def __find_print_version(self, html, base, referer):
         try:
             text = html.find(text=lambda t: t.strip().lower() in self.__print_version_keywords)
@@ -455,16 +469,18 @@ class Item:
         By extracting html document and reformatting it.
         """
         (html, self.__base, real_url) = self.__get_page_html(self.get_url_for_reformatter(self.__url))
-        if not self.__as_is:
-            if self.__try_use_print_version:
-                (html, self.__base, self.__tag) = self.__find_print_version(html, self.__base, real_url)
-            if not self.__tag and self.__next_page_keyword:
-                self.__next_page_a = self.__cache_next_page(html, self.__base)
-            if not self.__reformatter_url:
-                if self.__content_kwargs:
-                    self.__tag = html.body.find(**self.__content_kwargs)
-                if not self.__tag:
-                    self.__tag = self.__find_the_tag(html.body)
+        if self.__print_version_keywords:
+            (html, self.__base, self.__tag) = self.__find_print_version(html, self.__base, real_url)
+        sp = False
+        if not self.__tag and self.__single_page_keywords:
+            (html, self.__base, sp) = self.__find_single_page(html, self.__base, real_url)
+        if not sp and not self.__tag and self.__next_page_keywords:
+            self.__next_page_a = self.__cache_next_page(html, self.__base)
+        if not self.__reformatter_url:
+            if self.__content_kwargs:
+                self.__tag = html.body.find(**self.__content_kwargs)
+            if not self.__tag:
+                self.__tag = self.__find_the_tag(html.body)
         if not self.__tag:
             self.__tag = html.body
         title = html.find("title")
@@ -563,7 +579,7 @@ class Item:
                 f = open(filename, "r")
                 html = BeautifulSoup(f)
                 f.close()
-                self.__delete_cached_items(html.body, os.path.dirname(filename))
+                self.__delete_cached_items(html, os.path.dirname(filename))
             self.__report("deleting", filename)
             os.remove(filename)
 
@@ -588,10 +604,12 @@ class Feed:
     
     def __init__(self, url, path = "", cache_path = "", callback = None, title = None, filename = None,
         feed_template = None, feed_item_template = None, feed_update_template = None, page_template = None,
-        print_version_keywords = None, try_use_print_version = True, delete_before_date = None,
-        allow_scripts = False, inline_items = False, cache_items = False, include = None,
-        exclude = None, as_is = False, content_kwargs = None, reformatter_url = None,
-        next_page_keyword = None, new_window = False, always_clear_cache = False):
+        print_version_keywords = print_version_keywords_default,
+        single_page_keywords = single_page_keywords_default,
+        next_page_keywords = next_page_keywords_default,
+        delete_before_date = None, allow_scripts = False, inline_items = False, cache_items = False,
+        include = None, exclude = None, content_kwargs = None, reformatter_url = None,
+        new_window = False, always_clear_cache = False):
         """ Constructor.
 
         url - feed url.
@@ -604,18 +622,17 @@ class Feed:
         feed_item_template - html used to construct feed item.
         print_version_keywords - a list of phrases to scan html document searching for reference to
         printable version.
-        try_use_print_version - search for reference to printable version should be performed.
         delete_before_date - all items before this date are deleted during feed update.
         allow_scripts - do not remove script tags from item before caching.
         inline_items - inline referenced resources into feed html.
         cache_items - download and cache referenced resources.
         include - regexp for item urls to include.
         exclude - regexp for item urls to exclude.
-        as_is - do not try to reformat html document for small screens.
         content_kwargs - it is passed to BeautifulSoup's find method. It is usually
         tag name and its attributes.
         reformatter_url - format string (%s is replaced with url from item).
-        next_page_keyword - the name of the link that leads to the next page of document if any
+        next_page_keywords - a list of names of links which leads to the next page of document if any
+        single_page_keywords - a list of names of links which leads to the single page version
         new_window - True if you want all links in the feed to open new browser window.
         Used to process html document through online services such as Skweezer.
         """
@@ -638,7 +655,8 @@ class Feed:
         if feed_update_template:
             self.__feed_update_template = feed_update_template
         self.__print_version_keywords = print_version_keywords
-        self.__try_use_print_version = try_use_print_version
+        self.__single_page_keywords = single_page_keywords
+        self.__next_page_keywords = next_page_keywords
         self.__inline_items = inline_items
         self.__cache_items = cache_items
         self.__delete_before_date = delete_before_date
@@ -649,10 +667,8 @@ class Feed:
         self.__exclude = None
         if exclude:
             self.__exclude = re.compile(exclude)
-        self.__as_is = as_is
         self.__content_kwargs = content_kwargs
         self.__reformatter_url = reformatter_url
-        self.__next_page_keyword = next_page_keyword
         self.__new_window = new_window
         self.__always_clear_cache = always_clear_cache
         self.__downloader = Downloader(callback)
@@ -682,7 +698,7 @@ class Feed:
 
     def __get_item_date(self, item):
         tag = item.find(["pubdate", "published"])
-        if tag:
+        if tag and tag.string:
             try:
                 (date, zone) = parse_date(tag.string)
                 return date
@@ -729,10 +745,12 @@ class Feed:
         if cache_path == None:
             cache_path = self.__cache_path
         return Item(url = url, tag = tag, base = base, path = path, cache_path = cache_path,
-            callback = self.__callback, try_use_print_version = self.__try_use_print_version,
-            print_version_keywords = self.__print_version_keywords, allow_scripts = self.__allow_scripts,
-            as_is = self.__as_is, content_kwargs = self.__content_kwargs,
-            reformatter_url = self.__reformatter_url, next_page_keyword = self.__next_page_keyword,
+            callback = self.__callback,
+            print_version_keywords = self.__print_version_keywords,
+            single_page_keywords = self.__single_page_keywords,
+            next_page_keywords = self.__next_page_keywords,
+            allow_scripts = self.__allow_scripts, content_kwargs = self.__content_kwargs,
+            reformatter_url = self.__reformatter_url,
             downloader = self.__downloader, page_template = self.__page_template)
         
 
