@@ -20,6 +20,7 @@ import shutil
 import sys
 from BeautifulSoup import BeautifulStoneSoup
 
+version = "0.7.2"
 feed_template_default = """
 <html>
     <head>
@@ -30,7 +31,7 @@ feed_template_default = """
     </body>
 </html>
 """
-feed_style_default = "<style> body, table { font-size: large } </style>"
+feed_style_default = "<style> body, table { font-size: 15pt } </style>"
 custom_style = '<link rel="stylesheet" href="%(filename)s" type="text/css" />'
 
 gtk.gdk.threads_init()
@@ -38,7 +39,7 @@ gtk.gdk.threads_init()
 #This is to be able to start Feed Circuit on PC
 try:
     import osso
-    osso_context = osso.Context("org.maemo.feedcircuit", "0.7.1", False)
+    osso_context = osso.Context("org.maemo.feedcircuit", version, False)
 except ImportError:
     pass
 
@@ -201,10 +202,12 @@ class FeedConfig:
     mode_inline = 2
 
 
-    def __init__(self, cache_path, url, name, mode, days_to_keep,
-        include, exclude, ignore_print_version, icon_filename,
-        message_count, as_is, content_tag, print_version_link, reformatter_url,
-        next_page_link, checked, id = None):
+    def __init__(self, cache_path, url, name, mode, icon_filename,
+        days_to_keep = 7, include = "", exclude = "", message_count = 0,
+        content_tag = "", reformatter_url = "", checked = False, id = None,
+        print_version_keywords = feedcircuit.print_version_keywords_default,
+        single_page_keywords = feedcircuit.single_page_keywords_default,
+        next_page_keywords = feedcircuit.next_page_keywords_default):
         self.id = id
         if not self.id:
             self.id = uuid.uuid1().hex
@@ -215,14 +218,13 @@ class FeedConfig:
         self.days_to_keep = days_to_keep
         self.include = include
         self.exclude = exclude
-        self.ignore_print_version = ignore_print_version
         self.icon_filename = icon_filename
         self.message_count = message_count
-        self.as_is = as_is
-        self.content_tag = content_tag
-        self.print_version_link = print_version_link
         self.reformatter_url = reformatter_url
-        self.next_page_link = next_page_link
+        self.content_tag = content_tag
+        self.print_version_keywords = print_version_keywords
+        self.single_page_keywords = single_page_keywords
+        self.next_page_keywords = next_page_keywords
         self.icon = None
         self.iter = None
         self.ord_num = 0
@@ -258,9 +260,28 @@ class FeedConfig:
         return self.name
 
 
-    def get_print_version_keywords(self):
-        if self.print_version_link:
-            return [self.print_version_link, ]
+    def get_print_version_keywords_string(self):
+        return ",".join(self.print_version_keywords)
+
+
+    def set_print_version_keywords_string(self, keywords):
+        self.print_version_keywords = [str.strip().lower() for str in keywords.split(",")]
+
+
+    def get_single_page_keywords_string(self):
+        return ",".join(self.single_page_keywords)
+
+
+    def set_single_page_keywords_string(self, keywords):
+        self.single_page_keywords = [str.strip().lower() for str in keywords.split(",")]
+
+
+    def get_next_page_keywords_string(self):
+        return ",".join(self.next_page_keywords)
+
+
+    def set_next_page_keywords_string(self, keywords):
+        self.next_page_keywords = [str.strip().lower() for str in keywords.split(",")]
 
 
     def get_content_kwargs(self):
@@ -374,6 +395,24 @@ class FeedListModel(gtk.GenericTreeModel):
         return os.path.join(self.config_path, "config")
 
 
+    def load_config_1x71(self, parser, feed_config):
+        if parser.getboolean_default(feed_config.id, "as is", False):
+            feed_config.content_tag = ""
+            feed_config.print_version_keywords = []
+            feed_config.single_page_keywords = []
+            feed_config.next_page_keywords = []
+        else:
+            if parser.getboolean_default(feed_config.id, "ignore print version", False):
+                feed_config.print_version_keywords = []
+            else:
+                pvl = parser.get_default(feed_config.id, "print version link", "")
+                if pvl:
+                    feed_config.set_print_version_keywords_string(pvl)
+            npl = parser.get_default(feed_config.id, "next page link", "")
+            if npl:
+                feed_config.set_next_page_keywords_string(npl)
+
+
     def load_config(self):
         parser = ConfigParserEx()
         parser.read([self.get_config_file_name()])
@@ -383,6 +422,8 @@ class FeedListModel(gtk.GenericTreeModel):
         self.show_banner = parser.getboolean_default("global", "show banner", False)
         self.autorefresh_time = parser.get_default("global", "autorefresh time", "")
         self.connection_id = parser.get_default("global", "connection id", "")
+        self.autorefresh_checked = parser.getboolean_default("global", "autorefresh checked", False)
+        self.is_interval = parser.getboolean_default("global", "is interval", False)
         for section in parser.sections():
             if section != "global":
                 feed_config = FeedConfig(
@@ -390,20 +431,26 @@ class FeedListModel(gtk.GenericTreeModel):
                     parser.get(section, "url"),
                     parser.get(section, "name"),
                     parser.getint_default(section, "mode", FeedConfig.mode_ommit),
+                    parser.get_default(section, "icon", ""),
                     parser.getint_default(section, "days", 7),
                     parser.get_default(section, "include", ""),
                     parser.get_default(section, "exclude", ""),
-                    parser.getboolean_default(section, "ignore print version", False),
-                    parser.get_default(section, "icon", ""),
                     parser.getint_default(section, "message count", 0),
-                    parser.getboolean_default(section, "as is", False),
                     parser.get_default(section, "content tag", ""),
-                    parser.get_default(section, "print version link", ""),
                     parser.get_default(section, "reformatter url", ""),
-                    parser.get_default(section, "next page link", ""),
                     parser.getboolean_default(section, "checked", False),
                     section)
                 feed_config.ord_num = parser.getint_default(section, "order number", 0)
+                if parser.has_option(section, "print version keywords"):
+                    feed_config.set_print_version_keywords_string(
+                        parser.get(section, "print version keywords"))
+                if parser.has_option(section, "single page keywords"):
+                    feed_config.set_single_page_keywords_string(
+                        parser.get(section, "single page keywords"))
+                if parser.has_option(section, "next page keywords"):
+                    feed_config.set_next_page_keywords_string(
+                        parser.get(section, "next page keywords"))
+                self.load_config_1x71(parser, feed_config)
                 self.list.append(feed_config)
         self.list.sort(lambda f1, f2: f1.ord_num.__cmp__(f2.ord_num))
         self.rebuild_map()
@@ -420,6 +467,8 @@ class FeedListModel(gtk.GenericTreeModel):
             parser.set("global", "show banner", str(self.show_banner))
             parser.set("global", "autorefresh time", self.autorefresh_time)
             parser.set("global", "connection id", self.connection_id)
+            parser.set("global", "autorefresh checked", str(self.autorefresh_checked))
+            parser.set("global", "is interval", str(self.is_interval))
             i = 0
             for feed_config in self.list:
                 parser.add_section(feed_config.id)
@@ -429,16 +478,15 @@ class FeedListModel(gtk.GenericTreeModel):
                 parser.set(feed_config.id, "days", str(feed_config.days_to_keep))
                 parser.set(feed_config.id, "include", feed_config.include)
                 parser.set(feed_config.id, "exclude", feed_config.exclude)
-                parser.set(feed_config.id, "ignore print version", str(feed_config.ignore_print_version))
                 parser.set(feed_config.id, "icon", feed_config.icon_filename)
                 parser.set(feed_config.id, "message count", str(feed_config.message_count))
-                parser.set(feed_config.id, "as is", str(feed_config.as_is))
                 parser.set(feed_config.id, "content tag", feed_config.content_tag)
-                parser.set(feed_config.id, "print version link", feed_config.print_version_link)
                 parser.set(feed_config.id, "reformatter url", feed_config.reformatter_url)
-                parser.set(feed_config.id, "next page link", feed_config.next_page_link)
                 parser.set(feed_config.id, "checked", str(feed_config.checked))
                 parser.set(feed_config.id, "order number", str(i))
+                parser.set(feed_config.id, "print version keywords", feed_config.get_print_version_keywords_string())
+                parser.set(feed_config.id, "single page keywords", feed_config.get_single_page_keywords_string())
+                parser.set(feed_config.id, "next page keywords", feed_config.get_next_page_keywords_string())
                 i += 1
             parser.write(f)
         finally:
@@ -561,6 +609,13 @@ class AutorefreshWindow(gtk.Dialog):
         self.set_title(_("Automatic refresh"))
         self.enable_check = gtk.CheckButton()
         self.enable_check.connect("toggled", self.something_changed)
+        vbox = gtk.VBox()
+        self.time_radio = gtk.RadioButton(None, _("Refresh time"))
+        self.time_radio.set_sensitive(False)
+        vbox.pack_start(self.time_radio)
+        self.interval_radio = gtk.RadioButton(self.time_radio, _("Refresh interval"))
+        self.interval_radio.set_sensitive(False)
+        vbox.pack_start(self.interval_radio)
         self.time_editor = hildon.TimeEditor()
         self.time_editor.set_sensitive(False)
         self.conns = get_connections()
@@ -569,16 +624,21 @@ class AutorefreshWindow(gtk.Dialog):
         for conn in self.conns:
             self.connection_combo.append_text(conn[1])
         self.connection_combo.set_sensitive(False)
-        table = gtk.Table(rows = 2, columns = 2)
-        texts = [_("Refresh automatically"), _("Refresh time")]
-        #texts = [_("Refresh automatically"), _("Refresh time"), _("Connection")]
+        self.autorefresh_checked_check = gtk.CheckButton()
+        self.autorefresh_checked_check.set_sensitive(False)
+        table = gtk.Table(rows = 3, columns = 2)
+        texts = [_("Refresh automatically"), None, _("Selected only")]
+        #texts = [_("Refresh automatically"), None, _("Selected only"), _("Connection")]
         for i in range(0, len(texts)):
-            label = gtk.Label(texts[i])
-            label.set_alignment(1, 0.5)
-            table.attach(label, 0, 1, i, i + 1, xpadding = 3, ypadding = 3)
+            if texts[i]:
+                label = gtk.Label(texts[i])
+                label.set_alignment(1, 0.5)
+                table.attach(label, 0, 1, i, i + 1, xpadding = 3, ypadding = 3)
+        table.attach(vbox, 0, 1, 1, 2, xpadding = 3, ypadding = 3)
         table.attach(self.enable_check, 1, 2, 0, 1, xpadding = 3, ypadding = 3)
         table.attach(self.time_editor, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
-        #table.attach(self.connection_combo, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
+        table.attach(self.autorefresh_checked_check, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
+        #table.attach(self.connection_combo, 1, 2, 3, 4, xpadding = 3, ypadding = 3)
         self.vbox.add(table)
         self.show_all()
 
@@ -586,6 +646,9 @@ class AutorefreshWindow(gtk.Dialog):
     def something_changed(self, source):
         self.time_editor.set_sensitive(self.enable_check.get_active())
         self.connection_combo.set_sensitive(self.enable_check.get_active())
+        self.autorefresh_checked_check.set_sensitive(self.enable_check.get_active())
+        self.time_radio.set_sensitive(self.enable_check.get_active())
+        self.interval_radio.set_sensitive(self.enable_check.get_active())
 
 
     def get_connection_id(self):
@@ -610,6 +673,8 @@ class PreferencesWindow(gtk.Dialog):
         self.enable_autorefresh = False
         self.autorefresh_time = (0, 0, 0)
         self.connection_id = ""
+        self.autorefresh_checked = False
+        self.is_interval = False
         hbox = gtk.HBox()
         self.path_entry = gtk.Entry()
         self.path_entry.set_width_chars(24)
@@ -652,10 +717,14 @@ class PreferencesWindow(gtk.Dialog):
         dlg.enable_check.set_active(self.enable_autorefresh)
         dlg.time_editor.set_time(*self.autorefresh_time)
         dlg.set_connection_id(self.connection_id)
+        dlg.autorefresh_checked_check.set_active(self.autorefresh_checked)
+        dlg.interval_radio.set_active(self.is_interval)
         if dlg.run() == gtk.RESPONSE_ACCEPT:
             self.enable_autorefresh = dlg.enable_check.get_active()
             self.autorefresh_time = dlg.time_editor.get_time()
             self.connection_id = dlg.get_connection_id()
+            self.autorefresh_checked = dlg.autorefresh_checked_check.get_active()
+            self.is_interval = dlg.interval_radio.get_active()
         dlg.destroy()
 
 
@@ -758,49 +827,33 @@ class ContentWindow(gtk.Dialog):
             (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
              gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
         self.set_title(_("Content settings"))
-        self.as_is_button = gtk.CheckButton()
-        self.as_is_button.connect("toggled", self.something_changed)
         self.content_tag_entry = gtk.Entry()
         self.content_tag_entry.set_width_chars(24)
         self.content_tag_entry.connect("changed", self.something_changed)
         self.reformatter_url_entry = gtk.Entry()
         self.reformatter_url_entry.connect("changed", self.something_changed)
-        self.ignore_print_version_button = gtk.CheckButton()
-        self.ignore_print_version_button.connect("toggled", self.something_changed)
-        self.print_version_link_entry = gtk.Entry()
-        self.print_version_link_entry.connect("changed", self.something_changed)
-        self.next_page_link_entry = gtk.Entry()
-        self.next_page_link_entry.connect("changed", self.something_changed)
-        table = gtk.Table(rows = 6, columns = 2)
-        texts = [_("Use as is"), _("Content tag"), _("Reformatting service url"),
-            _("Ignore printable version"), _("Printable version link"), _("Next page link") ]
+        self.print_version_keywords_entry = gtk.Entry()
+        self.single_page_keywords_entry = gtk.Entry()
+        self.next_page_keywords_entry = gtk.Entry()
+        table = gtk.Table(rows = 5, columns = 2)
+        texts = [_("Content tag"), _("Reformatting service url"),
+            _("Printable version link"), _("Single page link"), _("Next page link") ]
         for i in range(0, len(texts)):
             label = gtk.Label(texts[i])
             label.set_alignment(1, 0.5)
             table.attach(label, 0, 1, i, i + 1, xpadding = 3, ypadding = 3)
-        table.attach(self.as_is_button, 1, 2, 0, 1, xpadding = 3, ypadding = 3)
-        table.attach(self.content_tag_entry, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
-        table.attach(self.reformatter_url_entry, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
-        table.attach(self.ignore_print_version_button, 1, 2, 3, 4, xpadding = 3, ypadding = 3)
-        table.attach(self.print_version_link_entry, 1, 2, 4, 5, xpadding = 3, ypadding = 3)
-        table.attach(self.next_page_link_entry, 1, 2, 5, 6, xpadding = 3, ypadding = 3)
+        table.attach(self.content_tag_entry, 1, 2, 0, 1, xpadding = 3, ypadding = 3)
+        table.attach(self.reformatter_url_entry, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
+        table.attach(self.print_version_keywords_entry, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
+        table.attach(self.single_page_keywords_entry, 1, 2, 3, 4, xpadding = 3, ypadding = 3)
+        table.attach(self.next_page_keywords_entry, 1, 2, 4, 5, xpadding = 3, ypadding = 3)
         self.vbox.add(table)
         self.show_all()
 
 
     def something_changed(self, source):
-        self.ignore_print_version_button.set_sensitive(not self.as_is_button.get_active())
-        self.print_version_link_entry.set_sensitive(
-            not self.as_is_button.get_active() and
-            not self.ignore_print_version_button.get_active() and
-            len(self.next_page_link_entry.get_text()) == 0)
-        self.content_tag_entry.set_sensitive(
-            not self.as_is_button.get_active() and len(self.reformatter_url_entry.get_text()) == 0)
-        self.reformatter_url_entry.set_sensitive(
-            not self.as_is_button.get_active() and len(self.content_tag_entry.get_text()) == 0)
-        self.next_page_link_entry.set_sensitive(
-            not self.as_is_button.get_active() and
-            len(self.print_version_link_entry.get_text()) == 0)
+        self.content_tag_entry.set_sensitive(len(self.reformatter_url_entry.get_text()) == 0)
+        self.reformatter_url_entry.set_sensitive(len(self.content_tag_entry.get_text()) == 0)
 
 
 class EditWindow(gtk.Dialog):
@@ -816,12 +869,11 @@ class EditWindow(gtk.Dialog):
         self.days_to_keep = feed_config.days_to_keep 
         self.include = feed_config.include
         self.exclude = feed_config.exclude
-        self.ignore_print_version = feed_config.ignore_print_version
-        self.as_is = feed_config.as_is
         self.content_tag = feed_config.content_tag
-        self.print_version_link = feed_config.print_version_link
         self.reformatter_url = feed_config.reformatter_url
-        self.next_page_link = feed_config.next_page_link
+        self.print_version_keywords = feed_config.get_print_version_keywords_string()
+        self.single_page_keywords = feed_config.get_single_page_keywords_string()
+        self.next_page_keywords = feed_config.get_next_page_keywords_string()
         hbox = gtk.HBox()
         self.url_entry = gtk.Entry()
         self.url_entry.set_width_chars(32)
@@ -872,12 +924,11 @@ class EditWindow(gtk.Dialog):
         self.feed_config.days_to_keep = self.days_to_keep
         self.feed_config.include = self.include
         self.feed_config.exclude = self.exclude
-        self.feed_config.as_is = self.as_is
-        self.feed_config.ignore_print_version = self.ignore_print_version
         self.feed_config.content_tag = self.content_tag
-        self.feed_config.print_version_link = self.print_version_link
         self.feed_config.reformatter_url = self.reformatter_url
-        self.feed_config.next_page_link = self.next_page_link
+        self.feed_config.set_print_version_keywords_string(self.print_version_keywords)
+        self.feed_config.set_single_page_keywords_string(self.single_page_keywords)
+        self.feed_config.set_next_page_keywords_string(self.next_page_keywords)
 
 
     def extra_clicked(self, source):
@@ -894,19 +945,17 @@ class EditWindow(gtk.Dialog):
 
     def content_clicked(self, source):
         cnt_window = ContentWindow(self)
-        cnt_window.as_is_button.set_active(self.as_is)
-        cnt_window.ignore_print_version_button.set_active(self.ignore_print_version)
         cnt_window.content_tag_entry.set_text(self.content_tag)
         cnt_window.reformatter_url_entry.set_text(self.reformatter_url)
-        cnt_window.print_version_link_entry.set_text(self.print_version_link)
-        cnt_window.next_page_link_entry.set_text(self.next_page_link)
+        cnt_window.print_version_keywords_entry.set_text(self.print_version_keywords)
+        cnt_window.single_page_keywords_entry.set_text(self.single_page_keywords)
+        cnt_window.next_page_keywords_entry.set_text(self.next_page_keywords)
         if cnt_window.run() == gtk.RESPONSE_ACCEPT:
-            self.as_is = cnt_window.as_is_button.get_active()
-            self.ignore_print_version = cnt_window.ignore_print_version_button.get_active()
             self.content_tag = cnt_window.content_tag_entry.get_text()
             self.reformatter_url = cnt_window.reformatter_url_entry.get_text()
-            self.print_version_link = cnt_window.print_version_link_entry.get_text()
-            self.next_page_link = cnt_window.next_page_link_entry.get_text()
+            self.print_version_keywords = cnt_window.print_version_keywords_entry.get_text()
+            self.single_page_keywords = cnt_window.single_page_keywords_entry.get_text()
+            self.next_page_keywords = cnt_window.next_page_keywords_entry.get_text()
         cnt_window.destroy()
 
 
@@ -1105,10 +1154,13 @@ class Program(hildon.Program):
         time = self.__model.get_autorefresh_time()
         if time:
             now = datetime.now()
-            next_time = datetime(now.year, now.month, now.day, time[0], time[1], time[2])
-            if next_time < (now + timedelta(seconds = 10)):
-                next_time = next_time + timedelta(1)
-            delta = next_time - now
+            if self.__model.is_interval:
+                delta = timedelta(hours = time[0], minutes = time[1], seconds = time[2])
+            else:
+                next_time = datetime(now.year, now.month, now.day, time[0], time[1], time[2])
+                if next_time < (now + timedelta(seconds = 10)):
+                    next_time = next_time + timedelta(1)
+                delta = next_time - now
             self.__timer_id = gobject.timeout_add(
                 (delta.days * 24 * 3600 + delta.seconds) * 1000, self.auto_refresh)
 
@@ -1283,15 +1335,16 @@ class Program(hildon.Program):
                                 clear_cache = False
                             feed = feedcircuit.Feed(url = url, path = self.__model.cache_path, cache_path = ".cache",
                                 title = title, filename = feed_config.get_filename(),
-                                callback = self.callback, try_use_print_version = not feed_config.ignore_print_version,
+                                callback = self.callback,
                                 delete_before_date = del_before, always_clear_cache = clear_cache,
                                 inline_items = feed_config.mode == FeedConfig.mode_inline,
                                 cache_items = feed_config.mode == FeedConfig.mode_cache,
                                 include = feed_config.include, exclude = feed_config.exclude,
-                                as_is = feed_config.as_is, content_kwargs = feed_config.get_content_kwargs(),
-                                print_version_keywords = feed_config.get_print_version_keywords(),
+                                print_version_keywords = feed_config.print_version_keywords,
+                                single_page_keywords = feed_config.single_page_keywords,
+                                next_page_keywords = feed_config.next_page_keywords,
                                 reformatter_url = feed_config.reformatter_url,
-                                next_page_keyword = feed_config.next_page_link,
+                                content_kwargs = feed_config.get_content_kwargs(),
                                 new_window = self.__model.use_new_window,
                                 feed_item_template = item_t, feed_update_template = update_t,
                                 page_template = page_t, feed_template = feed_t)
@@ -1315,8 +1368,12 @@ class Program(hildon.Program):
 
     def auto_refresh(self):
         try:
+            if self.__model.autorefresh_checked:
+                feeds = self.get_selected_feeds()
+            else:
+                feeds = list(self.__model.list)
             connect_and_exec(True, self.__model.connection_id,
-                self.update_feeds_async, list(self.__model.list))
+                self.update_feeds_async, feeds)
         finally:
             self.schedule_next_update()
 
@@ -1365,8 +1422,7 @@ class Program(hildon.Program):
                     message_format = _("Cannot discover feed at given url") + "\n" + str(ex))
                 msg_dlg.run()
                 msg_dlg.destroy()
-            feed_config = FeedConfig(self.__model.cache_path, url, title, FeedConfig.mode_ommit, 7, "", "", False, icon_filename, 0,
-                False, "", "", "", "", False)
+            feed_config = FeedConfig(self.__model.cache_path, url, title, FeedConfig.mode_ommit, icon_filename)
             edit_window = EditWindow(self.__window, feed_config)
             if edit_window.run() == gtk.RESPONSE_ACCEPT:
                 edit_window.update_feed()
@@ -1461,8 +1517,7 @@ class Program(hildon.Program):
                         msg_dlg.run()
                         msg_dlg.destroy()
                 feed_config = FeedConfig(self.__model.cache_path, outline["xmlurl"], outline["title"],
-                    FeedConfig.mode_ommit, 7, "", "", False, icon_file_name, 0,
-                    False, "", "", "", "", False)
+                    FeedConfig.mode_ommit, icon_file_name)
                 self.__model.append(feed_config)
         finally:
             f.close()
@@ -1523,6 +1578,8 @@ class Program(hildon.Program):
                 pref_window.enable_autorefresh = True
                 pref_window.autorefresh_time = time
                 pref_window.connection_id = self.__model.connection_id
+                pref_window.autorefresh_checked = self.__model.autorefresh_checked
+                pref_window.is_interval = self.__model.is_interval
             if pref_window.run() == gtk.RESPONSE_ACCEPT:
                 new_path = os.path.abspath(pref_window.path_entry.get_text())
                 if new_path != self.__model.cache_path:
@@ -1536,6 +1593,8 @@ class Program(hildon.Program):
                 if pref_window.enable_autorefresh:
                     self.__model.set_autorefresh_time(pref_window.autorefresh_time)
                     self.__model.connection_id = pref_window.connection_id
+                    self.__model.autorefresh_checked = pref_window.autorefresh_checked
+                    self.__model.is_interval = pref_window.is_interval
                 self.schedule_next_update()
                 self.check_col.set_visible(self.__model.use_checkboxes)
                 self.refresh_selected_item.set_property("visible", 
@@ -1554,7 +1613,7 @@ class Program(hildon.Program):
     def about(self, source):
         dialog = gtk.AboutDialog()
         dialog.set_name("FeedCircuit")
-        dialog.set_version("0.7.1")
+        dialog.set_version(version)
         dialog.set_website("http://feedcircuit.garage.maemo.org")
         dialog.set_authors([_("George Kibardin")])
         dialog.run()
